--- check_http.c	2007-05-18 16:43:08.875000000 +0100
+++ check_http.new.c	2007-05-18 16:46:25.640625000 +0100
@@ -119,6 +119,7 @@
 char *http_method;
 char *http_post_data;
 char *http_content_type;
+char *http_return_content_type;
 char buffer[MAX_INPUT_BUFFER];
 
 int process_arguments (int, char **);
@@ -196,6 +197,7 @@
     {"no-body", no_argument, 0, 'N'},
     {"max-age", required_argument, 0, 'M'},
     {"content-type", required_argument, 0, 'T'},
+    {"return-content-type", required_argument, 0, 'U'},
     {"pagesize", required_argument, 0, 'm'},
     {"invert-regex", no_argument, NULL, INVERT_REGEX},
     {"use-ipv4", no_argument, 0, '4'},
@@ -220,7 +222,7 @@
   }
 
   while (1) {
-    c = getopt_long (argc, argv, "Vvh46t:c:w:A:k:H:P:T:I:a:e:p:s:R:r:u:f:C:nlLSm:M:N", longopts, &option);
+    c = getopt_long (argc, argv, "Vvh46t:c:w:A:k:H:P:T:U:I:a:e:p:s:R:r:u:f:C:nlLSm:M:N", longopts, &option);
     if (c == -1 || c == EOF)
       break;
 
@@ -349,6 +351,9 @@
     case 'T': /* Content-type */
       asprintf (&http_content_type, "%s", optarg);
       break;
+    case 'U': /* Returned Content-type */
+      asprintf (&http_return_content_type, "%s", optarg);
+      break;
     case 'l': /* linespan */
       cflags &= ~REG_NEWLINE;
       break;
@@ -604,7 +609,65 @@
   }
 }
 
+static void
+check_header (const char *headers, const char *header_name, const char *match)
+{
+  const char *s;
+  char *header_value = 0;
 
+  s = headers;
+  while (*s) {
+    const char *field = s;
+    const char *value = 0;
+
+    /* Find the end of the header field */
+    while (*s && !isspace(*s) && *s != ':')
+      s++;
+
+    /* Remember the header value, if any. */
+    if (*s == ':')
+      value = ++s;
+
+    /* Skip to the end of the header, including continuation lines. */
+    while (*s && !(*s == '\n' && (s[1] != ' ' && s[1] != '\t')))
+      s++;
+    s++;
+
+    /* Process this header. */
+    if (value && value > field+2) {
+      char *ff = (char *) malloc (value-field);
+      char *ss = ff;
+      while (field < value-1)
+        *ss++ = tolower(*field++);
+      *ss++ = 0;
+
+      if (!strcmp (ff, header_name)) {
+        const char *e;
+        while (*value && isspace (*value))
+          value++;
+        for (e = value; *e && *e != '\r' && *e != '\n'; e++)
+          ;
+        ss = (char *) malloc (e - value + 1);
+        strncpy (ss, value, e - value);
+        ss[e - value] = 0;
+        if (header_value) free (header_value);
+        header_value = ss;
+      }
+      free (ff);
+    }
+  }
+
+  /* Done parsing the body.  Now check the header_value we (hopefully) parsed.  */
+  if (!header_value || !*header_value) {
+    die (STATE_UNKNOWN, _("HTTP UNKNOWN: %s header not found\n"), header_name);
+  } else {
+  	if (strcmp (header_value, match)) {
+  	  die (STATE_CRITICAL, _("HTTP CRITICAL: %s header is %s not %s\n"), header_name, header_value, match);
+  	}
+
+    free (header_value);
+  }
+}
 
 static void
 check_document_dates (const char *headers)
@@ -972,6 +1035,10 @@
           check_document_dates (header);
         }
 
+  if (http_return_content_type) {
+  	check_header (header, "content-type", http_return_content_type);
+  }
+
   /* check elapsed time */
   microsec = deltime (tv);
   elapsed_time = (double)microsec / 1.0e6;
@@ -1279,7 +1346,9 @@
   printf ("    %s\n", _("Warn if document is more than SECONDS old. the number can also be of"));
   printf ("    %s\n", _("the form \"10m\" for minutes, \"10h\" for hours, or \"10d\" for days."));
   printf (" %s\n", "-T, --content-type=STRING");
-  printf ("    %s\n", _("specify Content-Type header media type when POSTing\n"));
+  printf ("    %s\n", _("specify Content-Type header media type when POSTing"));
+  printf (" %s\n", "-U, --return-content-type=STRING");
+  printf ("    %s\n", _("specify Content-Type header media type that must be in the returned headers\n"));
 
   printf (" %s\n", "-l, --linespan");
   printf ("    %s\n", _("Allow regex to span newlines (must precede -r or -R)"));
@@ -1350,4 +1419,5 @@
   printf ("       [-a auth] [-f <ok | warn | critcal | follow>] [-e <expect>]\n");
   printf ("       [-s string] [-l] [-r <regex> | -R <case-insensitive regex>] [-P string]\n");
   printf ("       [-m <min_pg_size>:<max_pg_size>] [-4|-6] [-N] [-M <age>] [-A string] [-k string]\n");
+  printf ("       [-U <return-content-type>]\n");
 }
